==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/sites/lang/sites_co.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=co
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'En attente', # NEW
	'articles_meme_auteur' => 'Tous les articles de cet auteur', # NEW
	'articles_off' => 'Bloqués', # NEW
	'articles_publie' => 'Publiés', # NEW
	'articles_refuse' => 'Supprimés', # NEW
	'articles_tous' => 'Tous', # NEW
	'aucun_article_syndic' => 'Aucun article syndiqué', # NEW
	'avis_echec_syndication_01' => 'Hè fiascata a sindicazione : U backend indettatu ùn hè micca leghjitoghju, o puru prupone nisun artìculu.',
	'avis_echec_syndication_02' => 'Hè fiascata a sindicazione : Impussìbule d\'accede à u backend di stu situ.',
	'avis_site_introuvable' => 'Situ inesistente',
	'avis_site_syndique_probleme' => 'Attenti : Hè accaduta un\'errore durante a sindicazione di u situ; u sistema hè for\'d\'adopru per un tempu.
		Verificate l\'indirizzu di u schedariu di sindicazione di stu situ (<b>@url_syndic@</b>) è pruvate di novu à ricuarà l\'infurmazioni.',
	'avis_sites_probleme_syndication' => 'Ci sò stati i prublemi durante a sindicazione di sti siti',
	'avis_sites_syndiques_probleme' => 'Ci sò stati i prublemi durante a sindicazione di sti siti',

	// B
	'bouton_exporter' => 'Exporter', # NEW
	'bouton_importer' => 'Importer', # NEW
	'bouton_radio_modere_posteriori' => 'Muderazione dopu', # MODIF
	'bouton_radio_modere_priori' => 'muderazione in antìcipu', # MODIF
	'bouton_radio_non_syndication' => 'Nisuna sindicazione',
	'bouton_radio_syndication' => 'Sindicazione :',

	// C
	'confirmer_purger_syndication' => 'Êtes-vous certain de vouloir supprimer tous les articles syndiqués de ce site ?', # NEW

	// E
	'entree_adresse_fichier_syndication' => 'Indirizzu di u schedariu di sindicazione :',
	'entree_adresse_site' => '<b>Indirizzu di u situ</b> [Ubbligatoriu]',
	'entree_description_site' => 'Discrizzione di u situ',
	'erreur_fichier_format_inconnu' => 'Le format du fichier @fichier@ n\'est pas pris en charge.', # NEW
	'erreur_fichier_incorrect' => 'Impossible de lire le fichier.', # NEW

	// F
	'form_prop_nom_site' => 'Nome di u situ',

	// I
	'icone_article_syndic' => 'Article syndiqué', # NEW
	'icone_articles_syndic' => 'Articles syndiqués', # NEW
	'icone_controler_syndication' => 'Publication des articles syndiqués', # NEW
	'icone_modifier_site' => 'Mudificà u situ',
	'icone_referencer_nouveau_site' => 'Riferisce un novu situ',
	'icone_site_reference' => 'Sites référencés', # NEW
	'icone_supprimer_article' => 'Supprimer cet article', # NEW
	'icone_supprimer_articles' => 'Supprimer ces articles', # NEW
	'icone_valider_article' => 'Valider cet article', # NEW
	'icone_valider_articles' => 'Valider ces articles', # NEW
	'icone_voir_sites_references' => 'Vede i siti riferiti',
	'info_1_site_importe' => '1 site a été importé', # NEW
	'info_a_valider' => '[Da cunvalidà]',
	'info_aucun_site_importe' => 'Aucun site n\'a pu être importé', # NEW
	'info_bloquer' => 'bluccà',
	'info_bloquer_lien' => 'bluccà sta lea',
	'info_derniere_syndication' => 'L\'ùltima <em>sindicazione</em> di stu situ hè stata fatta ',
	'info_liens_syndiques_1' => 'lee sindicate',
	'info_liens_syndiques_2' => 'stanu in attesa di cunvalidazione.',
	'info_nb_sites_importes' => '@nb@ sites ont été importés', # NEW
	'info_nom_site_2' => '<b>Nome di u situ</b> [Ubbligatoriu]',
	'info_panne_site_syndique' => 'Situ sindicatu for\'d\'adopru',
	'info_probleme_grave' => 'prublemu di',
	'info_question_proposer_site' => 'Quale pò prupone siti riferiti ?',
	'info_retablir_lien' => 'ristabbilisce sta lea',
	'info_site_attente' => 'Situ Web in attesa di cunvàlida',
	'info_site_propose' => 'Situ prupostu u :',
	'info_site_reference' => 'Situ riferitu in ligna',
	'info_site_refuse' => 'Situ Web rifiutatu',
	'info_site_syndique' => 'Stu situ hè sindicatu ...', # MODIF
	'info_site_valider' => 'Siti da cunvalidà',
	'info_sites_referencer' => 'Riferisce un situ',
	'info_sites_refuses' => 'I siti rifiutati',
	'info_statut_site_1' => 'Stu situ hè :',
	'info_statut_site_2' => 'Pubblicatu',
	'info_statut_site_3' => 'Prupostu',
	'info_statut_site_4' => 'In a rumènzula', # MODIF
	'info_syndication' => 'sindicazione :',
	'info_syndication_articles' => 'artìculu/i',
	'item_bloquer_liens_syndiques' => 'Bluccà e lee sindicate per a cunvalidazione',
	'item_gerer_annuaire_site_web' => 'Gestisce un annuariu di siti Web',
	'item_non_bloquer_liens_syndiques' => 'Ùn bluccà micca e lee chì venenu da a sindicazione',
	'item_non_gerer_annuaire_site_web' => 'Disattivà l\'annuariu di i siti Web',
	'item_non_utiliser_syndication' => 'Ùn attivà micca a sindicazione autumàtica',
	'item_utiliser_syndication' => 'Attivà a sindicazione autumàtica',

	// L
	'label_exporter_avec_mots_cles_1' => 'Exporter les mots-clés sous forme de tags', # NEW
	'label_exporter_id_parent' => 'Exporter les sites de la rubrique', # NEW
	'label_exporter_publie_seulement_1' => 'Exporter uniquement les sites publiés', # NEW
	'label_fichier_import' => 'Fichier HTML', # NEW
	'label_importer_les_tags_1' => 'Importer les tags sous forme de mot-clé', # NEW
	'label_importer_statut_publie_1' => 'Publier automatiquement les sites', # NEW
	'lien_mise_a_jour_syndication' => 'Aghjurnà avà',
	'lien_nouvelle_recuperation' => 'Pruvà torna di ricuarà i dati',
	'lien_purger_syndication' => 'Effacer tous les articles syndiqués', # NEW

	// N
	'nombre_articles_syndic' => '@nb@ articles syndiqués', # NEW

	// S
	'statut_off' => 'Supprimé', # NEW
	'statut_prop' => 'En attente', # NEW
	'statut_publie' => 'Publié', # NEW
	'syndic_choix_moderation' => 'Cumu cumpurtà si cù e pròssime lee venendu da stu situ ?',
	'syndic_choix_oublier' => 'Cumu cumpurtà si cù e lee chì ùn ci sò più in u schedariu di sindicazione ?',
	'syndic_choix_resume' => 'Certi siti pruponenu u testu sanu sanu di l\'artìculi. In casu ch\'ellu sia dispunìbule, u vultete mette in sindicazione :',
	'syndic_lien_obsolete' => 'lea non più vàlida',
	'syndic_option_miroir' => 'bluccà le in autumàticu',
	'syndic_option_oubli' => 'sguassà le (dopu @mois@ mesi)',
	'syndic_option_resume_non' => 'u cuntenutu sanu sanu di l\'artìculi (in furmatu HTML)',
	'syndic_option_resume_oui' => 'un riassuntu solu (in furmatu testu)',
	'syndic_options' => 'Paràmetri per a sindicazione :',

	// T
	'texte_expliquer_export_bookmarks' => 'Vous pouvez exporter une liste de sites au format Marque-page HTML,
	pour vous permettre ensuite de l\'importer dans votre navigateur ou dans un service en ligne', # NEW
	'texte_expliquer_import_bookmarks' => 'Vous pouvez importer une liste de sites au format Marque-page HTML,
	en provenance de votre navigateur ou d\'un service en ligne de gestion des Marques-pages.', # NEW
	'texte_liens_sites_syndiques' => 'E lee chì venenu da siti sindicati 
			ponu esse bluccati; l\'opzione quì sottu face vede i paràmetri predefiniti di i siti sindicati dopu creati.
			Ferma quantunque pussìbule di sbluccà ogni sìngula lea, o di sceglie di bluccà e lee d\'ogni sìngulu situ.', # MODIF
	'texte_messages_publics' => 'Messagi pùbblichi di l\'artìculu :',
	'texte_non_fonction_referencement' => 'Pudete sceglie d\'ùn aduprà micca sta funzione autumàtica, ma rinsignà da per voi l\'elementi relativi à u situ ...', # MODIF
	'texte_referencement_automatique' => '<b>Riferimentu autumàtizatu d\'un situ</b><br />Pudete riferisce in furia un situ web rinsignendu ne quì sottu
		l\'indirizzu URL, o l\'indirizzu di u so schedariu di sindicazione. SPIP hà da ricuarà in autumàticu l\'infurmazioni relative à u situ
		(tìtulu, discrizzione...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Cuntrullate puru l\'infurmazioni furnite da <tt>@url@</tt> prima d\'arregistrà.',
	'texte_syndication' => 'Quandu un situ Web u permette, hè pussìbule di ricupreà ne in autumàticu a lista di e nutizie. Per quessa, Vi tocca à attivà 
		a sindicazione.	<blockquote><i>Certi òspiti disattiveghjanu sta funziunalità; in stu casu, ùn puderete micca aduprà a sindicazione di cuntenutu
		da u vostru situ.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Artìculi sindicati racolti da stu situ',
	'titre_dernier_article_syndique' => 'Ùltimi artìculi sindicati',
	'titre_exporter_bookmarks' => 'Exporter des Marques-pages', # NEW
	'titre_importer_bookmarks' => 'Importer des Marques-pages', # NEW
	'titre_importer_exporter_bookmarks' => 'Importer et Exporter des Marques-pages', # NEW
	'titre_page_sites_tous' => 'I siti riferiti',
	'titre_referencement_sites' => 'Riferimentu di siti è sindicazione',
	'titre_site_numero' => 'SITU NÙMERU :',
	'titre_sites_proposes' => 'I siti pruposti',
	'titre_sites_references_rubrique' => 'I siti riferiti in sta rùbbrica',
	'titre_sites_syndiques' => 'I siti sindicati',
	'titre_sites_tous' => 'I siti riferiti',
	'titre_syndication' => 'Sindicazione di siti',
	'tout_voir' => 'Voir tous les articles syndiqués', # NEW

	// U
	'un_article_syndic' => '1 article syndiqué' # NEW
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/sites/lang/sites_co.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=co
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'Hè fiascata a sindicazione : U backend indettatu ùn hè micca leghjitoghju, o puru prupone nisun artìculu.',
	'avis_echec_syndication_02' => 'Hè fiascata a sindicazione : Impussìbule d’accede à u backend di stu situ.',
	'avis_site_introuvable' => 'Situ inesistente',
	'avis_site_syndique_probleme' => 'Attenti : Hè accaduta un’errore durante a sindicazione di u situ; u sistema hè for’d’adopru per un tempu.
		Verificate l’indirizzu di u schedariu di sindicazione di stu situ (<b>@url_syndic@</b>) è pruvate di novu à ricuarà l’infurmazioni.',
	'avis_sites_probleme_syndication' => 'Ci sò stati i prublemi durante a sindicazione di sti siti',
	'avis_sites_syndiques_probleme' => 'Ci sò stati i prublemi durante a sindicazione di sti siti',

	// B
	'bouton_radio_modere_posteriori' => 'Muderazione dopu', # MODIF
	'bouton_radio_modere_priori' => 'muderazione in antìcipu', # MODIF
	'bouton_radio_non_syndication' => 'Nisuna sindicazione',
	'bouton_radio_syndication' => 'Sindicazione :',

	// E
	'entree_adresse_fichier_syndication' => 'Indirizzu di u schedariu di sindicazione :',
	'entree_adresse_site' => '<b>Indirizzu di u situ</b> [Ubbligatoriu]',
	'entree_description_site' => 'Discrizzione di u situ',

	// F
	'form_prop_nom_site' => 'Nome di u situ',

	// I
	'icone_modifier_site' => 'Mudificà u situ',
	'icone_referencer_nouveau_site' => 'Riferisce un novu situ',
	'icone_voir_sites_references' => 'Vede i siti riferiti',
	'info_1_site' => '1 situ',
	'info_a_valider' => '[Da cunvalidà]',
	'info_aucun_site' => 'Nisun situ',
	'info_bloquer' => 'bluccà',
	'info_bloquer_lien' => 'bluccà sta lea',
	'info_derniere_syndication' => 'L’ùltima <em>sindicazione</em> di stu situ hè stata fatta ',
	'info_liens_syndiques_1' => 'lee sindicate',
	'info_liens_syndiques_2' => 'stanu in attesa di cunvalidazione.',
	'info_nb_sites' => '@nb@ siti',
	'info_nom_site_2' => '<b>Nome di u situ</b> [Ubbligatoriu]',
	'info_panne_site_syndique' => 'Situ sindicatu for’d’adopru',
	'info_probleme_grave' => 'prublemu di',
	'info_question_proposer_site' => 'Quale pò prupone siti riferiti ?',
	'info_retablir_lien' => 'ristabbilisce sta lea',
	'info_site_attente' => 'Situ Web in attesa di cunvàlida',
	'info_site_propose' => 'Situ prupostu u :',
	'info_site_reference' => 'Situ riferitu in ligna',
	'info_site_refuse' => 'Situ Web rifiutatu',
	'info_site_syndique' => 'Stu situ hè sindicatu ...', # MODIF
	'info_site_valider' => 'Siti da cunvalidà',
	'info_sites_referencer' => 'Riferisce un situ',
	'info_sites_refuses' => 'I siti rifiutati',
	'info_statut_site_1' => 'Stu situ hè :',
	'info_statut_site_2' => 'Pubblicatu',
	'info_statut_site_3' => 'Prupostu',
	'info_statut_site_4' => 'In a rumènzula', # MODIF
	'info_syndication' => 'sindicazione :',
	'info_syndication_articles' => 'artìculu/i',
	'item_bloquer_liens_syndiques' => 'Bluccà e lee sindicate per a cunvalidazione',
	'item_gerer_annuaire_site_web' => 'Gestisce un annuariu di siti Web',
	'item_non_bloquer_liens_syndiques' => 'Ùn bluccà micca e lee chì venenu da a sindicazione',
	'item_non_gerer_annuaire_site_web' => 'Disattivà l’annuariu di i siti Web',
	'item_non_utiliser_syndication' => 'Ùn attivà micca a sindicazione autumàtica',
	'item_utiliser_syndication' => 'Attivà a sindicazione autumàtica',

	// L
	'lien_mise_a_jour_syndication' => 'Aghjurnà avà',
	'lien_nouvelle_recuperation' => 'Pruvà torna di ricuarà i dati',

	// S
	'syndic_choix_moderation' => 'Cumu cumpurtà si cù e pròssime lee venendu da stu situ ?',
	'syndic_choix_oublier' => 'Cumu cumpurtà si cù e lee chì ùn ci sò più in u schedariu di sindicazione ?',
	'syndic_choix_resume' => 'Certi siti pruponenu u testu sanu sanu di l’artìculi. In casu ch’ellu sia dispunìbule, u vultete mette in sindicazione :',
	'syndic_lien_obsolete' => 'lea non più vàlida',
	'syndic_option_miroir' => 'bluccà le in autumàticu',
	'syndic_option_oubli' => 'sguassà le (dopu @mois@ mesi)',
	'syndic_option_resume_non' => 'u cuntenutu sanu sanu di l’artìculi (in furmatu HTML)',
	'syndic_option_resume_oui' => 'un riassuntu solu (in furmatu testu)',
	'syndic_options' => 'Paràmetri per a sindicazione :',

	// T
	'texte_liens_sites_syndiques' => 'E lee chì venenu da siti sindicati 
			ponu esse bluccati; l’opzione quì sottu face vede i paràmetri predefiniti di i siti sindicati dopu creati.
			Ferma quantunque pussìbule di sbluccà ogni sìngula lea, o di sceglie di bluccà e lee d’ogni sìngulu situ.', # MODIF
	'texte_messages_publics' => 'Messagi pùbblichi di l’artìculu :',
	'texte_non_fonction_referencement' => 'Pudete sceglie d’ùn aduprà micca sta funzione autumàtica, ma rinsignà da per voi l’elementi relativi à u situ ...', # MODIF
	'texte_referencement_automatique' => '<b>Riferimentu autumàtizatu d’un situ</b><br />Pudete riferisce in furia un situ web rinsignendu ne quì sottu
		l’indirizzu URL, o l’indirizzu di u so schedariu di sindicazione. SPIP hà da ricuarà in autumàticu l’infurmazioni relative à u situ
		(tìtulu, discrizzione...).', # MODIF
	'texte_referencement_automatique_verifier' => 'Cuntrullate puru l’infurmazioni furnite da <tt>@url@</tt> prima d’arregistrà.',
	'texte_syndication' => 'Quandu un situ Web u permette, hè pussìbule di ricupreà ne in autumàticu a lista di e nutizie. Per quessa, Vi tocca à attivà 
		a sindicazione.	<blockquote><i>Certi òspiti disattiveghjanu sta funziunalità; in stu casu, ùn puderete micca aduprà a sindicazione di cuntenutu
		da u vostru situ.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Artìculi sindicati racolti da stu situ',
	'titre_dernier_article_syndique' => 'Ùltimi artìculi sindicati',
	'titre_page_sites_tous' => 'I siti riferiti',
	'titre_referencement_sites' => 'Riferimentu di siti è sindicazione',
	'titre_site_numero' => 'SITU NÙMERU :',
	'titre_sites_proposes' => 'I siti pruposti',
	'titre_sites_references_rubrique' => 'I siti riferiti in sta rùbbrica',
	'titre_sites_syndiques' => 'I siti sindicati',
	'titre_sites_tous' => 'I siti riferiti',
	'titre_syndication' => 'Sindicazione di siti'
);

?>
